Non-collinear transposing was buggy

The code for transposing + conjugating (adjoint operator)
was wrong for non-collinear matrices.
This is now finally fixed, and checked for.

Fixed documentation in ``trs`` method for matrices.

Fixed overlap conjugation for transpose when complex
numbers are used.
